from ChildProject.projects import ChildProject
from ChildProject.annotations import AnnotationManager
from ChildProject.metrics import segments_to_grid, conf_matrix

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
"""
This script build 2 confusion matrix for every recording of the dataset having vtc annotations.
The vtc annotations are compared against the eaf_cha set which only exists for the recording 'chain_inout.wav'
We allow annotations to be compared between different recordings only because all the recordings in this datasets are derived from the same audio source.
"""
speakers = ['CHI', 'OCH', 'FEM', 'MAL']
speakers_plot = speakers
#speakers_plot.append("None")
speakers_plot = [""] + speakers_plot

project = ChildProject('.')
am = AnnotationManager(project)
am.read()

anns = pd.DataFrame.copy(am.annotations)

human_ann = anns[anns['set'] == 'eaf_cha']
vtc_ann = anns[anns['set'] == 'vtc']

precisions = pd.DataFrame()

for i, row in vtc_ann.iterrows():
    audio_rec = row['recording_filename']
    virtual_index = pd.concat([human_ann, row.to_frame().T])
    virtual_index['recording_filename'] = 'placeholder' #must have the same name accross all annotations to trick intersection

    intersection = AnnotationManager.intersection(virtual_index, ['vtc', 'eaf_cha'])

    segments = am.get_collapsed_segments(intersection)
    segments = segments[segments['speaker_type'].isin(speakers)]

    #vtc = segments_to_grid(segments[segments['set'] == 'vtc'], 0, segments['segment_offset'].max(), 100, 'speaker_type', speakers,none = False)
    vtc = segments_to_grid(segments[segments['set'] == 'vtc'], 0, segments['segment_offset'].max(), 100, 'speaker_type', speakers)

    #its = segments_to_grid(segments[segments['set'] == 'its'], 0, segments['segment_offset'].max(), 100, 'speaker_type', speakers,none = False)
    eaf_cha = segments_to_grid(segments[segments['set'] == 'eaf_cha'], 0, segments['segment_offset'].max(), 100, 'speaker_type', speakers)

    confusion_counts = conf_matrix(vtc, eaf_cha)
    
    total = np.sum(confusion_counts)
    precision = np.trace(confusion_counts) / total if total != 0 else 0
    
    precisions = pd.concat([precisions, pd.DataFrame(data = {'recording_filename': [audio_rec],'precision': [precision]})])
    
    normalized = confusion_counts
    
    fig, ax = plt.subplots(figsize=(7.5, 7.5))
    ax.set_xticklabels(speakers_plot)  
    ax.set_yticklabels(speakers_plot)
    ax.matshow(normalized, cmap=plt.cm.Blues, alpha=0.3)
    for i in range(normalized.shape[0]):
        for j in range(normalized.shape[1]):
            ax.text(x=j, y=i,s=round(normalized[i, j],3), va='center', ha='center', size='xx-large')
     
    ax.xaxis.set_label_position("top")
    plt.xlabel('HUMAN', fontsize=18)
    plt.ylabel('VTC', fontsize=18)
    plt.title('Confusion Matrix', fontsize=18)
    plt.savefig('extra/reliability/{}.png'.format(audio_rec))

    normalized = confusion_counts/(np.sum(vtc, axis = 0)[:,None])

    fig, ax = plt.subplots(figsize=(7.5, 7.5))
    ax.set_xticklabels(speakers_plot)  
    ax.set_yticklabels(speakers_plot)
    ax.matshow(normalized, cmap=plt.cm.Blues, alpha=0.3)
    for i in range(normalized.shape[0]):
        for j in range(normalized.shape[1]):
            ax.text(x=j, y=i,s=round(normalized[i, j],3), va='center', ha='center', size='xx-large')
     
    ax.xaxis.set_label_position("top")
    plt.xlabel('HUMAN', fontsize=18)
    plt.ylabel('VTC', fontsize=18)
    plt.title('Confusion Matrix', fontsize=18)
    plt.savefig('extra/reliability/{}_normalized.png'.format(audio_rec))
    
    plt.close()

print(precisions)
precisions.to_csv('extra/reliability/precisions.csv',index=False)